@@ -31,12 +31,14 @@ Contact: yuvraaj@gmail.com
 LibContacts::LibContacts(IMainWindow *parent)
 : QObject(parent)
 , m_enableTimerUpdate(false)
+, m_reportUpdateFrequency(true) // Always report the frequency at the start
 , m_photoMutex(QMutex::Recursive)
 , m_simutaneousPhotoDownloads(0)
 , m_isFirstRefresh(true)
 , m_contactsModel(NULL)
 , m_searchedContactsModel(NULL)
 , m_contactPhonesModel(NULL)
+, m_contactStore(NULL)
 {
     Q_ASSERT(NULL != parent);
 
@@ -63,7 +65,8 @@ void
 LibContacts::init()
 {
     IMainWindow *win = (IMainWindow *) this->parent ();
-    api.initStore (win->db.createContactsStore ());
+    m_contactStore = win->db.createContactsStore ();
+    api.initStore (m_contactStore);
 }//LibContacts::init
 
 bool
@@ -97,6 +100,7 @@ LibContacts::logout()
 
     connect(task, SIGNAL(completed()), task, SLOT(deleteLater()));
     api.logout (task);
+    m_contactStore->logout ();
 }//LibContacts::logout
 
 void
@@ -174,6 +178,7 @@ LibContacts::refresh(QDateTime after /* = QDateTime()*/)
         win->db.setQuickAndDirty (false);
     }
 
+    win->uiShowStatusMessage ("Fetching contact updates", SHOW_INF);
     return (bval);
 }//LibContacts::refresh
 
@@ -248,22 +253,34 @@ LibContacts::afterFirstRefresh()
 void
 LibContacts::onContactsFetched()
 {
-    AsyncTaskToken *task = (AsyncTaskToken *) QObject::sender ();
-    task->deleteLater ();
-
     IMainWindow *win = (IMainWindow *) this->parent ();
     win->db.setQuickAndDirty (false);
 
-    MixPanelEvent mixEvent;
-    mixEvent.distinct_id = win->m_user;
-    mixEvent.event = "Contacts refresh";
+    AsyncTaskToken *task = (AsyncTaskToken *) QObject::sender ();
+    task->deleteLater ();
+
+    if (m_reportUpdateFrequency) {
+        m_reportUpdateFrequency = false;
+
+        MixPanelEvent mEvent;
+        mEvent.distinct_id = win->m_user;
+        mEvent.distinct_id = mEvent.distinct_id.toLower ();
+        mEvent.event = "Contacts refresh";
+        mEvent.properties["frequency"] = win->db.getInboxUpdateFreq ();
+        win->m_mixPanel.addEvent(mEvent);
+    }
+
+    win->uiShowStatusMessage ("Contacts fetched", SHOW_3SEC);
 
     if (ATTS_SUCCESS != task->status) {
         Q_WARN("Failed to update contacts");
 
         startNextPhoto ();
 
-        mixEvent.properties["fail"] = "true";
+        MixPanelEvent mixEvent;
+        mixEvent.distinct_id = win->m_user;
+        mixEvent.event = "Contacts refresh failed";
+        win->m_mixPanel.addEvent(mixEvent);
     } else {
         Q_DEBUG("Contacts updated.");
 
@@ -287,8 +304,6 @@ LibContacts::onContactsFetched()
         win->showStatusMessage ("Contacts fetched", SHOW_3SEC);
     }
 
-    win->m_mixPanel.addEvent(mixEvent);
-
     if (m_enableTimerUpdate && (m_updateTimer.interval () >= 60)) {
         m_updateTimer.stop ();
         m_updateTimer.start ();
@@ -601,6 +616,8 @@ LibContacts::setUpdateFrequency(quint32 mins)
     if (m_enableTimerUpdate) {
         win->db.setContactsUpdateFreq (mins);
         m_updateTimer.start ();
+
+        m_reportUpdateFrequency = true;
     }
 
     Q_DEBUG(QString("Update at %1 minute intervals set%2")
